==> hs-gtk-0.11.2p0.tgz: lib/ghc/gtk-0.11.2/register.sh <==
#!/bin/sh
echo 'name: gtk
version: 0.11.2
id: gtk-0.11.2-f028e886c42384bc69dd9b153654126c

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: This is the core library of the Gtk2Hs suite of libraries for Haskell
             based on Gtk+. Gtk+ is an extensive and mature multi-platform toolkit
             for creating graphical user interfaces.
category: Graphics
author: Axel Simon, Duncan Coutts and many others
pkgpath: x11/hs-gtk
exposed: True
exposed-modules: Graphics.UI.Gtk Graphics.UI.GtkInternals
                 Graphics.UI.Gtk.Abstract.Bin Graphics.UI.Gtk.Abstract.Box
                 Graphics.UI.Gtk.Abstract.ButtonBox
                 Graphics.UI.Gtk.Abstract.Container
                 Graphics.UI.Gtk.Abstract.IMContext Graphics.UI.Gtk.Abstract.Misc
                 Graphics.UI.Gtk.Abstract.Object Graphics.UI.Gtk.Abstract.Paned
                 Graphics.UI.Gtk.Abstract.Range Graphics.UI.Gtk.Abstract.Scale
                 Graphics.UI.Gtk.Abstract.Scrollbar
                 Graphics.UI.Gtk.Abstract.Separator Graphics.UI.Gtk.Abstract.Widget
                 Graphics.UI.Gtk.ActionMenuToolbar.Action
                 Graphics.UI.Gtk.ActionMenuToolbar.ActionGroup
                 Graphics.UI.Gtk.ActionMenuToolbar.RadioAction
                 Graphics.UI.Gtk.ActionMenuToolbar.ToggleAction
                 Graphics.UI.Gtk.ActionMenuToolbar.UIManager Graphics.UI.Gtk.Builder
                 Graphics.UI.Gtk.Buttons.Button Graphics.UI.Gtk.Buttons.CheckButton
                 Graphics.UI.Gtk.Buttons.RadioButton
                 Graphics.UI.Gtk.Buttons.ToggleButton Graphics.UI.Gtk.Cairo
                 Graphics.UI.Gtk.Display.AccelLabel Graphics.UI.Gtk.Display.Image
                 Graphics.UI.Gtk.Display.Label Graphics.UI.Gtk.Display.ProgressBar
                 Graphics.UI.Gtk.Display.Statusbar
                 Graphics.UI.Gtk.Display.StatusIcon
                 Graphics.UI.Gtk.Embedding.Embedding Graphics.UI.Gtk.Embedding.Plug
                 Graphics.UI.Gtk.Embedding.Socket Graphics.UI.Gtk.Entry.Editable
                 Graphics.UI.Gtk.Entry.Entry Graphics.UI.Gtk.Entry.EntryCompletion
                 Graphics.UI.Gtk.Entry.HScale Graphics.UI.Gtk.Entry.SpinButton
                 Graphics.UI.Gtk.Entry.VScale Graphics.UI.Gtk.Gdk.Cursor
                 Graphics.UI.Gtk.Gdk.Display Graphics.UI.Gtk.Gdk.Drawable
                 Graphics.UI.Gtk.Gdk.DrawWindow Graphics.UI.Gtk.Gdk.EventM
                 Graphics.UI.Gtk.Gdk.Events Graphics.UI.Gtk.Gdk.GC
                 Graphics.UI.Gtk.Gdk.Gdk Graphics.UI.Gtk.Gdk.Keys
                 Graphics.UI.Gtk.Gdk.Pixbuf Graphics.UI.Gtk.Gdk.PixbufAnimation
                 Graphics.UI.Gtk.Gdk.Pixmap Graphics.UI.Gtk.Gdk.Region
                 Graphics.UI.Gtk.Gdk.Screen Graphics.UI.Gtk.General.Clipboard
                 Graphics.UI.Gtk.General.Drag Graphics.UI.Gtk.General.General
                 Graphics.UI.Gtk.General.IconFactory
                 Graphics.UI.Gtk.General.IconTheme Graphics.UI.Gtk.General.RcStyle
                 Graphics.UI.Gtk.General.Selection
                 Graphics.UI.Gtk.General.StockItems Graphics.UI.Gtk.General.Style
                 Graphics.UI.Gtk.Layout.Alignment Graphics.UI.Gtk.Layout.AspectFrame
                 Graphics.UI.Gtk.Layout.Expander Graphics.UI.Gtk.Layout.Fixed
                 Graphics.UI.Gtk.Layout.HBox Graphics.UI.Gtk.Layout.HButtonBox
                 Graphics.UI.Gtk.Layout.HPaned Graphics.UI.Gtk.Layout.Layout
                 Graphics.UI.Gtk.Layout.Notebook Graphics.UI.Gtk.Layout.Table
                 Graphics.UI.Gtk.Layout.VBox Graphics.UI.Gtk.Layout.VButtonBox
                 Graphics.UI.Gtk.Layout.VPaned
                 Graphics.UI.Gtk.MenuComboToolbar.CheckMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Combo
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBox
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBoxEntry
                 Graphics.UI.Gtk.MenuComboToolbar.ImageMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Menu
                 Graphics.UI.Gtk.MenuComboToolbar.MenuBar
                 Graphics.UI.Gtk.MenuComboToolbar.MenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.MenuShell
                 Graphics.UI.Gtk.MenuComboToolbar.MenuToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.OptionMenu
                 Graphics.UI.Gtk.MenuComboToolbar.RadioMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.RadioToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorToolItem
                 Graphics.UI.Gtk.MenuComboToolbar.TearoffMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.ToggleToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.Toolbar
                 Graphics.UI.Gtk.MenuComboToolbar.ToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.ToolItem
                 Graphics.UI.Gtk.Misc.Adjustment Graphics.UI.Gtk.Misc.Arrow
                 Graphics.UI.Gtk.Misc.Calendar Graphics.UI.Gtk.Misc.DrawingArea
                 Graphics.UI.Gtk.Misc.EventBox Graphics.UI.Gtk.Misc.HandleBox
                 Graphics.UI.Gtk.Misc.IMMulticontext Graphics.UI.Gtk.Misc.SizeGroup
                 Graphics.UI.Gtk.Misc.Tooltip Graphics.UI.Gtk.Misc.Tooltips
                 Graphics.UI.Gtk.Misc.Viewport Graphics.UI.Gtk.ModelView
                 Graphics.UI.Gtk.ModelView.CellLayout
                 Graphics.UI.Gtk.ModelView.CellRenderer
                 Graphics.UI.Gtk.ModelView.CellRendererCombo
                 Graphics.UI.Gtk.ModelView.CellRendererPixbuf
                 Graphics.UI.Gtk.ModelView.CellRendererProgress
                 Graphics.UI.Gtk.ModelView.CellRendererText
                 Graphics.UI.Gtk.ModelView.CellRendererToggle
                 Graphics.UI.Gtk.ModelView.CellView
                 Graphics.UI.Gtk.ModelView.CustomStore
                 Graphics.UI.Gtk.ModelView.IconView
                 Graphics.UI.Gtk.ModelView.ListStore
                 Graphics.UI.Gtk.ModelView.TreeDrag
                 Graphics.UI.Gtk.ModelView.TreeModel
                 Graphics.UI.Gtk.ModelView.TreeModelFilter
                 Graphics.UI.Gtk.ModelView.TreeModelSort
                 Graphics.UI.Gtk.ModelView.TreeRowReference
                 Graphics.UI.Gtk.ModelView.TreeSelection
                 Graphics.UI.Gtk.ModelView.TreeSortable
                 Graphics.UI.Gtk.ModelView.TreeStore
                 Graphics.UI.Gtk.ModelView.TreeView
                 Graphics.UI.Gtk.ModelView.TreeViewColumn
                 Graphics.UI.Gtk.Multiline.TextBuffer
                 Graphics.UI.Gtk.Multiline.TextIter
                 Graphics.UI.Gtk.Multiline.TextMark
                 Graphics.UI.Gtk.Multiline.TextTag
                 Graphics.UI.Gtk.Multiline.TextTagTable
                 Graphics.UI.Gtk.Multiline.TextView Graphics.UI.Gtk.Ornaments.Frame
                 Graphics.UI.Gtk.Ornaments.HSeparator
                 Graphics.UI.Gtk.Ornaments.VSeparator
                 Graphics.UI.Gtk.Scrolling.HScrollbar
                 Graphics.UI.Gtk.Scrolling.ScrolledWindow
                 Graphics.UI.Gtk.Scrolling.VScrollbar
                 Graphics.UI.Gtk.Selectors.ColorButton
                 Graphics.UI.Gtk.Selectors.ColorSelection
                 Graphics.UI.Gtk.Selectors.ColorSelectionDialog
                 Graphics.UI.Gtk.Selectors.FileChooser
                 Graphics.UI.Gtk.Selectors.FileChooserButton
                 Graphics.UI.Gtk.Selectors.FileChooserDialog
                 Graphics.UI.Gtk.Selectors.FileChooserWidget
                 Graphics.UI.Gtk.Selectors.FileFilter
                 Graphics.UI.Gtk.Selectors.FileSelection
                 Graphics.UI.Gtk.Selectors.FontButton
                 Graphics.UI.Gtk.Selectors.FontSelection
                 Graphics.UI.Gtk.Selectors.FontSelectionDialog
                 Graphics.UI.Gtk.Windows.AboutDialog Graphics.UI.Gtk.Windows.Dialog
                 Graphics.UI.Gtk.Windows.Invisible
                 Graphics.UI.Gtk.Windows.MessageDialog
                 Graphics.UI.Gtk.Windows.Window Graphics.UI.Gtk.Windows.WindowGroup
                 Graphics.UI.Gtk.General.Enums
hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                Graphics.UI.Gtk.Gdk.PixbufData Graphics.UI.Gtk.General.Structs
                Graphics.UI.Gtk.ModelView.Types Graphics.UI.Gtk.ModelView.Sequence
                Graphics.UI.Gtk.Multiline.Types
                Graphics.UI.Gtk.Abstract.ContainerChildProperties
                Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
import-dirs: /usr/local/lib/ghc/gtk-0.11.2
library-dirs: /usr/local/lib/ghc/gtk-0.11.2 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HSgtk-0.11.2
extra-libraries: gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0 Xinerama Xi
                 Xrandr Xcursor Xcomposite atk-1.0 cairo pixman-1 GL drm Xxf86vm
                 Xext Xdamage Xfixes xcb-shm xcb-render Xrender xcb pthread-stubs
                 Xau Xdmcp gdk_pixbuf-2.0 png gio-2.0 pangoft2-1.0 X11 pango-1.0 m
                 gobject-2.0 gthread-2.0 gmodule-2.0 glib-2.0 intl iconv fontconfig
                 expat freetype z
extra-ghci-libraries:
include-dirs: /usr/local/include/gtk-2.0
              /usr/local/lib/gtk-2.0/include /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/X11R6/include
              /usr/local/include/cairo /usr/local/include/atk-1.0
              /usr/X11R6/include/pixman-1 /usr/include/dev/pci/drm
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/libpng
              /usr/local/include/glib-2.0 /usr/local/lib/glib-2.0/include
              /usr/X11R6/include/freetype2
includes:
depends: array-0.3.0.1-438000c197b51c147f229b54edbf632e
         base-4.2.0.2-578c91f7479ca9d00c13da2ed514f7ac
         bytestring-0.9.1.7-41dd05a497806d68d10ffae5438a0632
         cairo-0.11.1-bc156cfe9b73f481ca51dcfc98fcd21a
         containers-0.3.0.0-ee442470d8dcc9e45f31677c400c5379
         gio-0.11.1-5805a962bc6404decfdcc0ae5d8ee442
         glib-0.11.2-a66d7389df9efabefed61626dcd2e232
         haskell98-1.0.1.1-4d2891ad99eae334ff8234bcfbddce06
         mtl-1.1.0.2-9e35d291e0ab20c6aa18823de23bc2de
         pango-0.11.2-c2c901f50481e93c1d42ec82db27a25c
hugs-options:
cc-options:
ld-options: -R/usr/X11R6/lib -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-gtk-0.11.2/html/gtk.haddock
haddock-html: /usr/local/share/doc/hs-gtk-0.11.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gtk-0.12.0p1.tgz: lib/ghc/gtk-0.12.0/register.sh <==
#!/bin/sh
echo 'name: gtk
version: 0.12.0
id: gtk-0.12.0-7dcdd93cfdbc36dc65e2bd7fe32e4978

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: This is the core library of the Gtk2Hs suite of libraries for Haskell
             based on Gtk+. Gtk+ is an extensive and mature multi-platform toolkit
             for creating graphical user interfaces.
category: Graphics
author: Axel Simon, Duncan Coutts and many others
pkgpath: x11/hs-gtk
exposed: True
exposed-modules: Graphics.UI.Gtk Graphics.UI.GtkInternals
                 Graphics.UI.Gtk.Abstract.Bin Graphics.UI.Gtk.Abstract.Box
                 Graphics.UI.Gtk.Abstract.ButtonBox
                 Graphics.UI.Gtk.Abstract.Container
                 Graphics.UI.Gtk.Abstract.IMContext Graphics.UI.Gtk.Abstract.Misc
                 Graphics.UI.Gtk.Abstract.Object Graphics.UI.Gtk.Abstract.Paned
                 Graphics.UI.Gtk.Abstract.Range Graphics.UI.Gtk.Abstract.Scale
                 Graphics.UI.Gtk.Abstract.Scrollbar
                 Graphics.UI.Gtk.Abstract.Separator Graphics.UI.Gtk.Abstract.Widget
                 Graphics.UI.Gtk.ActionMenuToolbar.Action
                 Graphics.UI.Gtk.ActionMenuToolbar.ActionGroup
                 Graphics.UI.Gtk.ActionMenuToolbar.RadioAction
                 Graphics.UI.Gtk.ActionMenuToolbar.RecentAction
                 Graphics.UI.Gtk.ActionMenuToolbar.ToggleAction
                 Graphics.UI.Gtk.ActionMenuToolbar.UIManager Graphics.UI.Gtk.Builder
                 Graphics.UI.Gtk.Buttons.Button Graphics.UI.Gtk.Buttons.CheckButton
                 Graphics.UI.Gtk.Buttons.RadioButton
                 Graphics.UI.Gtk.Buttons.ToggleButton
                 Graphics.UI.Gtk.Buttons.LinkButton
                 Graphics.UI.Gtk.Buttons.ScaleButton
                 Graphics.UI.Gtk.Buttons.VolumeButton Graphics.UI.Gtk.Cairo
                 Graphics.UI.Gtk.Display.AccelLabel Graphics.UI.Gtk.Display.Image
                 Graphics.UI.Gtk.Display.Label Graphics.UI.Gtk.Display.ProgressBar
                 Graphics.UI.Gtk.Display.Spinner Graphics.UI.Gtk.Display.Statusbar
                 Graphics.UI.Gtk.Display.StatusIcon Graphics.UI.Gtk.Display.InfoBar
                 Graphics.UI.Gtk.Embedding.Embedding Graphics.UI.Gtk.Embedding.Plug
                 Graphics.UI.Gtk.Embedding.Socket Graphics.UI.Gtk.Entry.Editable
                 Graphics.UI.Gtk.Entry.Entry Graphics.UI.Gtk.Entry.EntryBuffer
                 Graphics.UI.Gtk.Entry.EntryCompletion Graphics.UI.Gtk.Entry.HScale
                 Graphics.UI.Gtk.Entry.SpinButton Graphics.UI.Gtk.Entry.VScale
                 Graphics.UI.Gtk.Gdk.AppLaunchContext Graphics.UI.Gtk.Gdk.Cursor
                 Graphics.UI.Gtk.Gdk.Keymap Graphics.UI.Gtk.Gdk.Display
                 Graphics.UI.Gtk.Gdk.DisplayManager Graphics.UI.Gtk.Gdk.Drawable
                 Graphics.UI.Gtk.Gdk.DrawWindow Graphics.UI.Gtk.Gdk.EventM
                 Graphics.UI.Gtk.Gdk.Events Graphics.UI.Gtk.Gdk.GC
                 Graphics.UI.Gtk.Gdk.Gdk Graphics.UI.Gtk.Gdk.Keys
                 Graphics.UI.Gtk.Gdk.Pixbuf Graphics.UI.Gtk.Gdk.PixbufAnimation
                 Graphics.UI.Gtk.Gdk.Pixmap Graphics.UI.Gtk.Gdk.Region
                 Graphics.UI.Gtk.Gdk.Screen Graphics.UI.Gtk.General.Clipboard
                 Graphics.UI.Gtk.General.Drag Graphics.UI.Gtk.General.General
                 Graphics.UI.Gtk.General.IconFactory
                 Graphics.UI.Gtk.General.IconTheme Graphics.UI.Gtk.General.RcStyle
                 Graphics.UI.Gtk.General.Selection
                 Graphics.UI.Gtk.General.StockItems Graphics.UI.Gtk.General.Style
                 Graphics.UI.Gtk.Layout.Alignment Graphics.UI.Gtk.Layout.AspectFrame
                 Graphics.UI.Gtk.Layout.Expander Graphics.UI.Gtk.Layout.Fixed
                 Graphics.UI.Gtk.Layout.HBox Graphics.UI.Gtk.Layout.HButtonBox
                 Graphics.UI.Gtk.Layout.HPaned Graphics.UI.Gtk.Layout.Layout
                 Graphics.UI.Gtk.Layout.Notebook Graphics.UI.Gtk.Layout.Table
                 Graphics.UI.Gtk.Layout.VBox Graphics.UI.Gtk.Layout.VButtonBox
                 Graphics.UI.Gtk.Layout.VPaned
                 Graphics.UI.Gtk.MenuComboToolbar.CheckMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Combo
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBox
                 Graphics.UI.Gtk.MenuComboToolbar.ComboBoxEntry
                 Graphics.UI.Gtk.MenuComboToolbar.ImageMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.Menu
                 Graphics.UI.Gtk.MenuComboToolbar.MenuBar
                 Graphics.UI.Gtk.MenuComboToolbar.MenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.MenuShell
                 Graphics.UI.Gtk.MenuComboToolbar.MenuToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.OptionMenu
                 Graphics.UI.Gtk.MenuComboToolbar.RadioMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.RadioToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.SeparatorToolItem
                 Graphics.UI.Gtk.MenuComboToolbar.TearoffMenuItem
                 Graphics.UI.Gtk.MenuComboToolbar.ToggleToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.Toolbar
                 Graphics.UI.Gtk.MenuComboToolbar.ToolButton
                 Graphics.UI.Gtk.MenuComboToolbar.ToolItem
                 Graphics.UI.Gtk.MenuComboToolbar.ToolItemGroup
                 Graphics.UI.Gtk.MenuComboToolbar.ToolPalette
                 Graphics.UI.Gtk.Misc.Accessible Graphics.UI.Gtk.Misc.Adjustment
                 Graphics.UI.Gtk.Misc.Arrow Graphics.UI.Gtk.Misc.Calendar
                 Graphics.UI.Gtk.Misc.DrawingArea Graphics.UI.Gtk.Misc.EventBox
                 Graphics.UI.Gtk.Misc.HandleBox Graphics.UI.Gtk.Misc.IMMulticontext
                 Graphics.UI.Gtk.Misc.IMContextSimple Graphics.UI.Gtk.Misc.SizeGroup
                 Graphics.UI.Gtk.Misc.Tooltip Graphics.UI.Gtk.Misc.Tooltips
                 Graphics.UI.Gtk.Misc.Viewport Graphics.UI.Gtk.ModelView
                 Graphics.UI.Gtk.ModelView.CellEditable
                 Graphics.UI.Gtk.ModelView.CellLayout
                 Graphics.UI.Gtk.ModelView.CellRenderer
                 Graphics.UI.Gtk.ModelView.CellRendererSpinner
                 Graphics.UI.Gtk.ModelView.CellRendererCombo
                 Graphics.UI.Gtk.ModelView.CellRendererPixbuf
                 Graphics.UI.Gtk.ModelView.CellRendererProgress
                 Graphics.UI.Gtk.ModelView.CellRendererText
                 Graphics.UI.Gtk.ModelView.CellRendererAccel
                 Graphics.UI.Gtk.ModelView.CellRendererSpin
                 Graphics.UI.Gtk.ModelView.CellRendererToggle
                 Graphics.UI.Gtk.ModelView.CellView
                 Graphics.UI.Gtk.ModelView.CustomStore
                 Graphics.UI.Gtk.ModelView.IconView
                 Graphics.UI.Gtk.ModelView.ListStore
                 Graphics.UI.Gtk.ModelView.TreeDrag
                 Graphics.UI.Gtk.ModelView.TreeModel
                 Graphics.UI.Gtk.ModelView.TreeModelFilter
                 Graphics.UI.Gtk.ModelView.TreeModelSort
                 Graphics.UI.Gtk.ModelView.TreeRowReference
                 Graphics.UI.Gtk.ModelView.TreeSelection
                 Graphics.UI.Gtk.ModelView.TreeSortable
                 Graphics.UI.Gtk.ModelView.TreeStore
                 Graphics.UI.Gtk.ModelView.TreeView
                 Graphics.UI.Gtk.ModelView.TreeViewColumn
                 Graphics.UI.Gtk.Multiline.TextBuffer
                 Graphics.UI.Gtk.Multiline.TextIter
                 Graphics.UI.Gtk.Multiline.TextMark
                 Graphics.UI.Gtk.Multiline.TextTag
                 Graphics.UI.Gtk.Multiline.TextTagTable
                 Graphics.UI.Gtk.Multiline.TextView Graphics.UI.Gtk.Ornaments.Frame
                 Graphics.UI.Gtk.Ornaments.HSeparator
                 Graphics.UI.Gtk.Ornaments.VSeparator
                 Graphics.UI.Gtk.Printing.PaperSize
                 Graphics.UI.Gtk.Printing.PageSetup
                 Graphics.UI.Gtk.Printing.PrintContext
                 Graphics.UI.Gtk.Printing.PrintOperation
                 Graphics.UI.Gtk.Printing.PrintSettings
                 Graphics.UI.Gtk.Recent.RecentChooserMenu
                 Graphics.UI.Gtk.Recent.RecentChooserWidget
                 Graphics.UI.Gtk.Recent.RecentFilter
                 Graphics.UI.Gtk.Recent.RecentManager
                 Graphics.UI.Gtk.Recent.RecentInfo
                 Graphics.UI.Gtk.Recent.RecentChooser
                 Graphics.UI.Gtk.Scrolling.HScrollbar
                 Graphics.UI.Gtk.Scrolling.ScrolledWindow
                 Graphics.UI.Gtk.Scrolling.VScrollbar
                 Graphics.UI.Gtk.Selectors.ColorButton
                 Graphics.UI.Gtk.Selectors.ColorSelection
                 Graphics.UI.Gtk.Selectors.ColorSelectionDialog
                 Graphics.UI.Gtk.Selectors.FileChooser
                 Graphics.UI.Gtk.Selectors.FileChooserButton
                 Graphics.UI.Gtk.Selectors.FileChooserDialog
                 Graphics.UI.Gtk.Selectors.FileChooserWidget
                 Graphics.UI.Gtk.Selectors.FileFilter
                 Graphics.UI.Gtk.Selectors.FileSelection
                 Graphics.UI.Gtk.Selectors.FontButton
                 Graphics.UI.Gtk.Selectors.FontSelection
                 Graphics.UI.Gtk.Selectors.FontSelectionDialog
                 Graphics.UI.Gtk.Selectors.HSV Graphics.UI.Gtk.Special.Ruler
                 Graphics.UI.Gtk.Special.HRuler Graphics.UI.Gtk.Special.VRuler
                 Graphics.UI.Gtk.Windows.AboutDialog
                 Graphics.UI.Gtk.Windows.Assistant Graphics.UI.Gtk.Windows.Dialog
                 Graphics.UI.Gtk.Windows.Invisible
                 Graphics.UI.Gtk.Windows.MessageDialog
                 Graphics.UI.Gtk.Windows.Window
                 Graphics.UI.Gtk.Windows.OffscreenWindow
                 Graphics.UI.Gtk.Windows.WindowGroup Graphics.UI.Gtk.General.Enums
hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                Graphics.UI.Gtk.Gdk.PixbufData Graphics.UI.Gtk.General.Structs
                Graphics.UI.Gtk.ModelView.Types Graphics.UI.Gtk.ModelView.Sequence
                Graphics.UI.Gtk.Multiline.Types
                Graphics.UI.Gtk.Abstract.ContainerChildProperties
                Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
import-dirs: /usr/local/lib/ghc/gtk-0.12.0
library-dirs: /usr/local/lib/ghc/gtk-0.12.0 /usr/local/lib
              /usr/X11R6/lib
hs-libraries: HSgtk-0.12.0
extra-libraries: gthread-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
                 Xext Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes atk-1.0
                 cairo pixman-1 pthread-stubs GL png xcb-shm xcb-render xcb Xrender
                 X11 gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m gobject-2.0
                 glib-2.0 intl iconv fontconfig expat freetype z
extra-ghci-libraries:
include-dirs: /usr/local/include/gtk-2.0
              /usr/local/lib/gtk-2.0/include /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/X11R6/include
              /usr/local/include/cairo /usr/local/include/atk-1.0
              /usr/X11R6/include/pixman-1 /usr/include/dev/pci/drm
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/libpng
              /usr/local/include/glib-2.0 /usr/local/lib/glib-2.0/include
              /usr/local/include /usr/X11R6/include/freetype2
includes:
depends: array-0.3.0.2-143060371bda4ff52c270d1067551fe8
         base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
         cairo-0.12.0-0f0db7bd16540db34af2e7f3a09ec4bc
         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
         gio-0.12.0-99d30ef09e181ca08d871b72e0923b31
         glib-0.12.0-6c035e26ff59497b45e0ba131f8e7109
         haskell98-1.1.0.1-77a2638462dcb3e7c4b25de628e54ca6
         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
         pango-0.12.0-6defb18f3b0a95dc8750a2e7e2b75f47
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-gtk-0.12.0/html/gtk.haddock
haddock-html: /usr/local/share/doc/hs-gtk-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
